@@ -85,7 +85,6 @@ class BaseExecutor(Module):
 
     EVENTS = Module.EVENTS + ('task', )
 
-    logger_name = 'executor'
     _loop_task: asyncio.Future
     _routers: List[TaskRouter]
     _unit_monitor_task: asyncio.Future
@@ -500,10 +499,10 @@ class BaseExecutor(Module):
         """
         exc = processing_fut.exception()
         if processing_fut.cancelled():
-            self.logger.debug(f"Task '{task}' execution cancelled internally")
+            self.logger.info(f"CANCELLED: Task '{task.task_type} (uuid={task.uuid})' execution cancelled internally")
             return
         elif exc is not None:
-            self.logger.warning(f"Task '{task}' execution failed with exception {exc.__class__.__name__}({exc})")
+            self.logger.warning(f"ERROR: Task '{task.task_type} (uuid={task.uuid})' execution failed with exception {exc.__class__.__name__}({exc})")
             handlers = self._get_exception_handler(exc)
             finalized = False
 
@@ -522,7 +521,8 @@ class BaseExecutor(Module):
                     self.logger.exception(f"exception handler failed: {exc.__class__.__name__}({exc})")
                     if self.worker.debug:
                         raise exc
-
+        else:
+            self.logger.info(f"DONE: Task '{task.task_type} (uuid={task.uuid})' processing completed")
         await self._commit_task(task, receiver)
 
     async def _handle_task_control(self, task: Task, exc: Exception):
